IIASA Scenario Explorer metadata
********************************

Each instance of the IIASA Scenario Explorer (e.g. https://data.ene.iiasa.ac.at/ar6/) requires a distinct collection of information about the structure of model output data to be accepted.
The process of providing this structure information is termed **“model registration,”** and is partly documented at https://nomenclature-iamc.readthedocs.io, including the expected `directory and file layout <https://nomenclature-iamc.readthedocs.io/en/stable/user_guide/directory-structure.html>`_.
The process must be repeated for additional Scenario Explorer instances.

:mod:`message_ix_models` includes, in :file:`data/iiasa-se/`, files that can be used for such registration.
As of 2022-08-15, these are exactly the files use in the NAVIGATE project instance of the Scenario Explorer.
These files **should**:

- …match the actual structure and metadata of models/scenarios generated by :mod:`message_ix_models`,
- …be used as the basis for, and/or be updated to match, files used for registration in other Scenario Explorer instances.

.. contents::
   :local:
   :backlinks: none

:file:`mappings-R12.yaml`
=========================

This file would be placed at e.g. :file:`mappings/MESSAGEix-GLOBIOM_1.1-R12.yaml` in a registration repository.

.. literalinclude:: ../../message_ix_models/data/iiasa-se/mappings-R12.yaml
   :language: yaml

:file:`def-regions.yaml`
========================

This file would be placed at e.g. :file:`definitions/region/MESSAGEix-GLOBIOM_1.1-R12.yaml` in a registration repository.

.. literalinclude:: ../../message_ix_models/data/iiasa-se/def-regions.yaml
   :language: yaml
